<?php

namespace Drupal\recurly_aegir\Processors;

use Drupal\node\Entity\Node;
use Drupal\recurly_aegir\Processors\RecurlyAegirProcessor;
use Drupal\recurly_aegir\Provisioners\RecurlyAegirSiteDeleteProvisioner;

/**
 * Processes expired subscriptions.
 */
class RecurlyAegirSubscriptionExpiredProcessor extends RecurlyAegirProcessor {

  public function process() {
    // Ensure required configuration isn't missing.
    if (empty($endpoint = $this->getServiceEndpoint())) {
      $this->result = FALSE;
      return $this;
    }

    // Fetch IDs for the user and subscription.
    $user_id = $this->getUserId($this->account);
    $subscription_uuid = (string) $this->subscription->uuid;

    // Find sites associated with this subscription.
    $site_ids = \Drupal::entityQuery('node')
        ->condition('type', 'recurly_aegir_site')
        ->condition('uid', $user_id)
        ->condition('field_site_subscription_url', $this->getSubscriptionUrl($subscription_uuid))
        ->execute();

    // Delete each one.
    foreach (array_values($site_ids) as $site_id) {
      $site = Node::load($site_id);
      $provisioner = new RecurlyAegirSiteDeleteProvisioner($endpoint, $site->getTitle());

      $this->launchSiteProvisioner($site, $provisioner);

      // Save the site as it contains an updated task log.
      $site->save();
    }

    // Set the result and return.
    $this->result = TRUE;
    return $this;
  }

}
