<?php

namespace Drupal\recurly_aegir\Provisioners;

use Drupal\recurly_aegir\Provisioners\RecurlyAegirSiteProvisioner;

/**
 * Base class for cloning new sites via Aegir's Web service API.
 */
class RecurlyAegirSiteCloneProvisioner extends RecurlyAegirSiteProvisioner {

  /**
   * The human-readable task type used by this privisioner.
   */
  const TASK_TYPE = 'Clone';

  /**
   * {@inheritdoc}
   */
  public function __construct($endpoint, $hostname, $template = NULL) {
    parent::__construct($endpoint, $hostname, $template);

    // Ensure mandatory parameters are set.
    if (empty($template)) {
      throw new Exception('Site-creation provisioners must be provided with a template on construction.');
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getTaskType() {
    return self::TASK_TYPE;
  }

  /**
   * {@inheritdoc}
   *
   * Provisions new sites via clone tasks.
   */
  public function provision() {
    $this->sendRequestAndReceiveResponse([
      // Task type.
      'type' => strtolower($this->getTaskType()),
      // Source.
      'nid' => $this->template,
      'options' => [
        // Destination.
        'new_uri' => $this->hostname,
      ],
    ]);

    return $this;
  }

}
